create_table: Normalize a table from a data_set

Description Usage Arguments Value Examples

Description

Normalize a table from a data_set

Usage

1
create_table(dataframe, vector, nid = 4)

Arguments

dataframe

non-normalized dataframe sorted from columns with largest number of factors to smallest

vector

The vector (sorted non-increasing) that shows uniqueness of each table

Value

None, but creates the new normalized tables in the current directory.

Examples

1
create_table(dataframe, vector)

Hashim94/data-scraping-package documentation built on May 6, 2019, 10:55 p.m.