Description Usage Arguments Value Examples
Normalize a table from a data_set
1 | create_table(dataframe, vector, nid = 4)
|
dataframe |
non-normalized dataframe sorted from columns with largest number of factors to smallest |
vector |
The vector (sorted non-increasing) that shows uniqueness of each table |
None, but creates the new normalized tables in the current directory.
1 | create_table(dataframe, vector)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.